@@ -3,12 +3,11 @@ from typing import Any
 
 
 class Bucket(metaclass=ABCMeta):
-    def __init__(self, name: str):
-        self._name = name
 
     @abstractmethod
     def get_object_link(self, key: str) -> str:
-        """获取文件的下载链接
+        """
+        获取文件的下载链接
 
         :param key: 文件的名称
         """
@@ -23,7 +22,8 @@ class Bucket(metaclass=ABCMeta):
 
 
 class ObjStore(metaclass=ABCMeta):
-    """提供文件存储服务
+    """
+    提供文件存储服务
     """
 
     @abstractmethod
